@@ -1,9 +1,8 @@
 package Hadoop::HDFS::Command;
-$Hadoop::HDFS::Command::VERSION = '0.003';
+$Hadoop::HDFS::Command::VERSION = '0.004';
 use 5.010;
 use strict;
 use warnings;
-
 use Capture::Tiny   ();
 use Carp            ();
 use Data::Dumper;
@@ -37,10 +36,10 @@ has enable_log => (
     lazy    => 1,
 );
 
-has 'runas' => (
+has runas => (
     is      => 'rw',
     isa     => Str,
-    default => getpwuid $<,
+    default => scalar getpwuid $<,
     lazy    => 1,
 );
 
@@ -556,7 +555,7 @@ Hadoop::HDFS::Command
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
